module ApiBackend
  class BaseController < ApplicationController
  protect_from_forgery with: :null_session

  before_action :authenticate

  private

  def find_user_by_auth_token(token)
    raise "Please impliment 'find_user_by_auth_token(token)' in your API controller"
  end

  def current_user
    @current_user
  end

  def authenticate
    authenticate_token || render_unauthorized
  end

  def authenticate_token
    authenticate_with_http_token do |token, options|
      @current_user = find_user_by_auth_token(token)
    end
  end

  def render_unauthorized
    self.headers['WWW-Authenticate'] = 'Token realm="Application"'
    render json: 'Bad credentials', status: 401
  end

  def render_errors_for(model)
    render json: {
      message: 'Validation Failed',
      errors: model.errors.full_messages
    }, status: 422
  end

  def save_and_render(model)
    if model.save
      render
    else
      render_errors_for(model)
    end
  end

  def update_and_render(model, attributes)
    if model.update_attributes(attributes)
      render
    else
      render_errors_for(model)
    end
  end
end

end